<?php

/* --------------------------------------------------------------
   LinkPageContent.inc.php 2019-04-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class LinkPageContent
 *
 * This class represents a link page content entity
 *
 * @category   System
 * @package    Content
 */
class LinkPageContent
    implements ContentAttributesInterface, ContentNameAttributeInterface, ContentLinkAttributesInterface
{
    /**
     * Content type
     *
     * @var string
     */
    protected $type;
    
    /**
     * Content position
     *
     * @var string
     */
    protected $position;
    
    /**
     * Content is active
     *
     * @var bool
     */
    protected $status;
    
    /**
     * Localized content titles
     *
     * @var ContentTitleCollection
     */
    protected $titles;
    
    
    /**
     * Localized content names
     *
     * @var ContentNameCollection
     */
    protected $names;
    
    /**
     * Localized content links
     *
     * @var ContentLinkCollection
     */
    protected $links;
    
    /**
     * content is opening in new tab
     *
     * @var bool
     */
    protected $opensInNewTabStatus;
    
    
    /**
     * LinkPageContent constructor
     *
     * @param ContentPositionInterface $pagePosition Page position
     * @param ContentStatusInterface $status Activation status
     * @param ContentTitleCollection $titles Localized titles
     * @param ContentNameCollection $names Localized names
     * @param ContentLinkCollection $links Localized links
     * @param ContentOpenInNewTabStatus $opensInNewTabStatus Whether the link is opened in a new tab
     */
    public function __construct(
        ContentPositionInterface $pagePosition,
        ContentStatusInterface $status,
        ContentTitleCollection $titles,
        ContentNameCollection $names,
        ContentLinkCollection $links,
        ContentOpenInNewTabStatus $opensInNewTabStatus
    ) {
        $this->type = ContentType::createForContent()->type();
        $this->position = $pagePosition->position();
        $this->status = $status->isActive();
        $this->titles = $titles;
        $this->names = $names;
        $this->links = $links;
        $this->opensInNewTabStatus = $opensInNewTabStatus->opensInNewTab();
    }
    
    
    /**
     * Return the content type
     *
     * @return string
     */
    public function type()
    {
        return $this->type;
    }
    
    
    /**
     * Return the content position
     *
     * @return string
     */
    public function position()
    {
        return $this->position;
    }
    
    
    /**
     * Return whether the content is active
     *
     * @return bool
     */
    public function isActive()
    {
        return $this->status;
    }
    
    
    /**
     * Return the localized content titles
     *
     * @return ContentTitleCollection
     */
    public function titles()
    {
        return $this->titles;
    }
    
    
    /**
     * Return the localized content names
     *
     * @return ContentNameCollection
     */
    public function names()
    {
        return $this->names;
    }
    
    
    /**
     * Return the localized content links
     *
     * @return ContentLinkCollection
     */
    public function links()
    {
        return $this->links;
    }
    
    
    /**
     * Return whether the content is opened in a new tab
     *
     * @return bool
     */
    public function isOpeningInNewTab()
    {
        return $this->opensInNewTabStatus;
    }
}