<?php

/* --------------------------------------------------------------
   ContentTitle.inc.php 2019-04-11
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class ContentTitle
 *
 * This class represents the localized content title
 *
 * @category   System
 * @package    Content
 */
class ContentTitle implements LocalizedContentAttributeInterface
{
    /**
     * Content title
     *
     * @var StringType
     */
    protected $title;
    
    /**
     * Language code
     *
     * @var string
     */
    protected $languageCode;
    
    
    /**
     * ContentTitle constructor
     *
     * @param \StringType $title Content title
     * @param LanguageCode $languageCode Language code
     */
    public function __construct(StringType $title, LanguageCode $languageCode)
    {
        if (!strlen($title->asString())) {
            throw new InvalidArgumentException('Empty title provided');
        }
        
        $this->title = $title;
        $this->languageCode = $languageCode->asString();
    }
    
    
    /**
     * Return the content title
     *
     * @return string
     */
    public function content()
    {
        return $this->title->asString();
    }
    
    
    /**
     * Return the language code
     *
     * @return string
     */
    public function languageCode()
    {
        return $this->languageCode;
    }
}