<?php
/* --------------------------------------------------------------
   gm_get_session_name_postfix.inc.php 2019-04-16
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Returns a postfix value for the session cookie name.
 *
 * The postfix is specific to the installation of the shop system. Thus, multiple installations can coexist on the
 * same domain without interfering with each other’s sessions. This could otherwise happen if installations exist e.g.
 * on https://example.com/ and https://subshop.example.com/ because the cookie path ("/") is identical and a session
 * cookie for the installation on example.com would also get sent to the subdomain subshop.example.com.
 * Another way around this problem would be to limit session cookies to the exact host name which in turn might cause
 * problems for installations which allow access via example.com and www.example.com.
 *
 * cf. https://developer.mozilla.org/en-US/docs/Web/HTTP/Cookies#Scope_of_cookies
 *
 * @return string
 */
function gm_get_session_name_postfix()
{
    $sessionNamePostfix = (string)substr(hash('sha256', mt_rand()), 0 , 16);
    $sessionNamePostfixFiles = glob(DIR_FS_CATALOG . 'media/session_name_postfix_*');
    if (empty($sessionNamePostfixFiles)) {
        if (!is_writable(DIR_FS_CATALOG . 'media')) {
            throw new RuntimeException('media directory MUST be writable!');
        }
        file_put_contents(DIR_FS_CATALOG . 'media/session_name_postfix_' . $sessionNamePostfix, "this file is intentionally empty.\n");
    } else if (count($sessionNamePostfixFiles) > 1) {
        throw new RuntimeException('multiple session name postfix files detected');
    } else { // count($sessionNamePostfixFiles) === 1
        $sessionNamePostfixFile = array_pop($sessionNamePostfixFiles);
        $sessionNamePostfix = (string)str_replace('session_name_postfix_', '', basename($sessionNamePostfixFile));
    }
    if (empty($sessionNamePostfix)) {
        throw new RuntimeException('could not determine session name postfix');
    }
    return $sessionNamePostfix;
}
